vdoc.methods.cli package | vdoc 0.19.0 documentation

Skip to content

# vdoc.methods.cli package

## Submodules

## vdoc.methods.cli.cli_run_method module

Contains all CLI methods for running the application.

vdoc.methods.cli.cli_run_method.run_impl(bind_address, bind_port)

  Starts the FastAPI app with the given parameters.

  Parameters:

    - bind_address (`str`) – The bind address of the application.

    - bind_port (`int`) – The bind port of the application.

  Return type:

    `None`

## Module contents

Contains all CLI methods.

vdoc.methods.api package
vdoc.models package